{
  stdenv,
  lib,
  fetchurl,
  ptlib,
  pkgs,
}:

let
  version = "3.18.6";
  downloadPath = lib.strings.escapeURL "v3.18 Cygni/Stable 6/opal-3.18.6";
in
stdenv.mkDerivation {
  pname = "opal";
  inherit version;

  src = fetchurl {
    url = "mirror://sourceforge/opalvoip/${downloadPath}.tar.bz2";
    hash = "sha256-L/0784mYza2p866Fal5pvvQ4IJjC9b5VSFwQ89jSYUw=";
  };

  nativeBuildInputs = with pkgs; [ pkg-config ];
  buildInputs =
    (with pkgs; [
      openssl
      spandsp
      srtp
      libopus
    ])
    ++ [ ptlib ];

  # configureFlags = [
  #   # "--with-openssl-dir=${pkgs.openssl.dev}"
  #   "--disable-srtp"
  # ];

  enableParallelBuilding = true;
  strictDeps = true;
  doCheck = true;

  configurePhase = ''
    PTLIBPLUGINDIR="${ptlib}/lib/ptlib-${ptlib.version}:$out/lib/opal-${version}"
    ./configure --prefix=$out
  '';

  meta = {
    description = "OPAL";
    homepage = "https://sourceforge.net/projects/opalvoip/";
    platforms = with lib.platforms; unix;
    license = lib.licenses.mpl10;
    downloadPage = "https://sourceforge.net/projects/opalvoip/files/";
  };
}
