{
  stdenv,
  lib,
  fetchurl,
  pkgs,
}:

let
  version = "2.18.6";
  downloadPath = lib.strings.escapeURL "v3.18 Cygni/Stable 6/ptlib-2.18.6";
in
stdenv.mkDerivation {
  pname = "ptlib";
  inherit version;

  src = fetchurl {
    url = "mirror://sourceforge/opalvoip/${downloadPath}.tar.bz2";
    hash = "sha256-31HndbsCS73uU0yvJW7/YA7s56+9V2itafuLPqllE2Y=";
  };

  nativeBuildInputs = with pkgs; [ pkg-config ];
  buildInputs = with pkgs; [
    flex
    bison
  ];

  enableParallelBuilding = true;
  strictDeps = true;
  doCheck = true;

  configurePhase = ''
    PTLIBPLUGINDIR="$out/lib/ptlib-${version}"
    ./configure --prefix=$out
  '';

  meta = {
    description = "ptlib";
    homepage = "https://sourceforge.net/projects/opalvoip/";
    platforms = with lib.platforms; unix;
    license = lib.licenses.mpl10;
    downloadPage = "https://sourceforge.net/projects/opalvoip/files/";
  };
}
